package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcOutsourceWork;

/**
 * 委外工作Service接口
 * 
 * @author cmc
 * @date 2024-09-19
 */
public interface ICmcOutsourceWorkService 
{
    /**
     * 查询委外工作
     * 
     * @param workId 委外工作主键
     * @return 委外工作
     */
    public CmcOutsourceWork selectCmcOutsourceWorkByWorkId(Integer workId);

    /**
     * 查询委外工作列表
     * 
     * @param cmcOutsourceWork 委外工作
     * @return 委外工作集合
     */
    public List<CmcOutsourceWork> selectCmcOutsourceWorkList(CmcOutsourceWork cmcOutsourceWork);

    /**
     * 新增委外工作
     * 
     * @param cmcOutsourceWork 委外工作
     * @return 结果
     */
    public int insertCmcOutsourceWork(CmcOutsourceWork cmcOutsourceWork);

    /**
     * 修改委外工作
     * 
     * @param cmcOutsourceWork 委外工作
     * @return 结果
     */
    public int updateCmcOutsourceWork(CmcOutsourceWork cmcOutsourceWork);

    /**
     * 批量删除委外工作
     * 
     * @param outsourceIds 需要删除的委外工作主键集合
     * @return 结果
     */
    public int deleteCmcOutsourceWorkByOutsourceIds(String[] outsourceIds);

    /**
     * 删除委外工作信息
     * 
     * @param workId 委外工作主键
     * @return 结果
     */
    public int deleteCmcOutsourceWorkByWorkId(Integer workId);
}
